@@ -21,10 +21,10 @@ import sys
 import pytest
 
 # Local packages
-import tomas_misc.tpo_common as tpo
-from tomas_misc import debug
-from tomas_misc.main import Main
-from tomas_misc.unittest_wrapper import TestWrapper
+import mezcla.tpo_common as tpo
+from mezcla import debug
+from mezcla.main import Main
+from mezcla.unittest_wrapper import TestWrapper
 
 class MyArgumentParser(ArgumentParser):
     """Version of ArgumentParser that doesn't exit upon failure"""
@@ -50,7 +50,7 @@ class TestIt(TestWrapper):
     def test_script_options(self):
         """Makes sure script option specifications are parsed OK"""
         debug.trace(4, "test_script_options()")
-        from tomas_misc.main import Main  # pylint: disable=import-outside-toplevel, redefined-outer-name, reimported
+        from mezcla.main import Main  # pylint: disable=import-outside-toplevel, redefined-outer-name, reimported
         class Test(Main):
             """"Dummy test class"""
             argument_parser = MyArgumentParser
@@ -75,7 +75,7 @@ class TestIt(TestWrapper):
 
         # Create scriptlet checking for input and processing main step
         # TODO: rework with external script as argparse exits upon failure
-        from tomas_misc.main import Main  # pylint: disable=import-outside-toplevel, redefined-outer-name, reimported
+        from mezcla.main import Main  # pylint: disable=import-outside-toplevel, redefined-outer-name, reimported
         class Test(Main):
             """"Dummy test class"""
             argument_parser = MyArgumentParser
