@@ -29,10 +29,10 @@ import sys
 ## import textract
 
 # Local packages
-from tomas_misc import debug
-from tomas_misc.my_regex import my_re
-from tomas_misc import system
-from tomas_misc.system import to_int
+from mezcla import debug
+from mezcla.my_regex import my_re
+from mezcla import system
+from mezcla.system import to_int
 
 # TEMP: Placeholders for dynamically loaded modules
 BeautifulSoup = None
